FalconSign extension

Signing concern of Falcon.

on

Methods

sign(SecretKey sk, Uint8List message, {RandomBytes? randombytes}) Uint8List

Available on Falcon, provided by the FalconSign extension

Sign message with sk. If randombytes is provided it is used both as the salt source and to seed the per-attempt ChaCha20 sampler, making the signature reproducible (and byte-identical to the reference). When null, a secure source is used directly.