FalconUtils class

This file contains methods and objects which are reused through multiple files.

Constructors

FalconUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

merge(List<List<num>> fList) List<num>
Merge two polynomials into a single polynomial f.
split(List<num> f) List<List<num>>
Split a polynomial f in two polynomials.
sqnorm(List<List<num>> v) num
Compute the square euclidean norm of the vector v.

Constants

q → const int
q is the integer modulus which is used in Falcon.