LdlFft class

Result of an LDL* decomposition of a 2x2 Gram matrix: G = L * D * L^*.

Constructors

LdlFft(List<List<List<Complex>>> l, List<List<List<Complex>>> d)
const

Properties

d List<List<List<Complex>>>
Diagonal factor; d[0][0] and d[1][1] carry the information.
final
hashCode int
The hash code for this object.
no setterinherited
l List<List<List<Complex>>>
Lower-triangular factor; only l[1][0] is non-trivial.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited