sign/api/falcon_params library
Classes
- FalconParams
-
Falcon parameter sets and protocol constants, copied verbatim from the
reference
falcon.py.
Constants
-
falconParams
→ const Map<
int, FalconParams> - falconQ → const int
- The integer modulus used in Falcon.
- headLen → const int
- Bytelengths of the signing header, salt and per-signature seed.
-
logn
→ const Map<
int, int> - log2(n) per parameter set, used in the signature header byte (0x30 + logn).
- saltLen → const int
- seedLen → const int