FalconParams class
Falcon parameter sets and protocol constants, copied verbatim from the
reference falcon.py.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → int
-
Ring dimension / polynomial degree (a power of two, 2..1024).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sigBound → int
-
Upper bound on ||s0||^2 + ||s1||^2 for an accepted signature.
final
- sigBytelen → int
-
Byte length of an encoded signature (header + salt + compressed s1).
final
- sigma → double
-
Standard deviation of signatures (Gaussians over the lattice).
final
- sigmin → double
-
Lower bound on the std. dev. of each Gaussian over Z.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited