SecretKey class
A Falcon secret key: the NTRU polynomials (f, g, F, G), the FFT of the
lattice basis B0 = [g, -f, G, -F], and the normalized ffLDL tree used
for fast Fourier sampling during signing.
Constructors
Properties
-
b0Fft
→ List<
List< List< >Complex> > -
B0 in FFT representation:
[[a, b], [c, d]] = [[g, -f], [G, -F]].final -
bigF
→ List<
int> -
final
-
bigG
→ List<
int> -
final
-
f
→ List<
int> -
final
-
g
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → int
-
no setter
- param → FalconParams
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tFft → FfTree
-
The normalized ffLDL decomposition tree.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited