Complex class
Complex number class for FFT operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- imaginary → double
-
final
- magnitude → double
-
Magnitude (absolute value) of the complex number
no setter
- phase → double
-
Phase (argument) of the complex number
no setter
- real → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
conjugate(
) → Complex - Complex conjugate
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
Object other) → Complex - Multiplication
-
operator +(
Object other) → Complex - Addition
-
operator -(
Object other) → Complex - Subtraction
-
operator /(
Object other) → Complex - Division
-
operator ==(
Object other) → bool -
The equality operator.
override
-
operator unary-(
) → Complex - Unary negation